# Changelog

## v0.1.0 - 2025-07-29

**Improvements**:

- Improved initial project scaffolding and modular structure.
- Enhanced configuration for easier customization and extension.

**New Features**:

- Added preprocessing module with various image scaling options:
  - MeanCentering
  - MinMaxScaler
  - StandardScaler
  - RobustScaler
- Added analysis module including easy implementation of PCA with explained variance calculation.
- Added new example notebooks.
